# TextPreprocessing

This is the beta release of TextPreprocessing library. This library currenly capable of cleansing your text data for modal training.

TextPreprocessing library can do the below actions:

    * Expand general abbreviations
    * Clear email ids in the text data
    * Clear web URLs
    * Clear html tags present in the text dataset
    * Clear gibberish charsets
    * Lemetize the text
    * Correct spelling errors.

We are enhancing this package on a regular basis and adding more flexible components to it in the upcoming releases. Please do update this package on frequently.


